@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -17,7 +17,6 @@ use Composer\Filter\PlatformRequirementFilter\PlatformRequirementFilterFactory;
 use Composer\Filter\PlatformRequirementFilter\PlatformRequirementFilterInterface;
 use Composer\Package\BasePackage;
 use Composer\Package\AliasPackage;
-use Composer\Repository\PlatformRepository;
 
 /**
  * @author Nils Adermann <naderman@naderman.de>
@@ -57,7 +56,7 @@ class RuleSetGenerator
      *
      * @phpstan-param ReasonData $reasonData
      */
-    protected function createRequireRule(BasePackage $package, array $providers, $reason, $reasonData = null)
+    protected function createRequireRule(BasePackage $package, array $providers, $reason, $reasonData = null): ?Rule
     {
         $literals = array(-$package->id);
 
@@ -81,12 +80,12 @@ class RuleSetGenerator
      * @param  BasePackage[] $packages   The set of packages to choose from
      * @param  Rule::RULE_*  $reason     A RULE_* constant describing the reason for
      *                                   generating this rule
-     * @param  array         $reasonData Additional data like the root require or fix request info
+     * @param  mixed         $reasonData Additional data like the root require or fix request info
      * @return Rule          The generated rule
      *
      * @phpstan-param ReasonData $reasonData
      */
-    protected function createInstallOneOfRule(array $packages, $reason, $reasonData)
+    protected function createInstallOneOfRule(array $packages, $reason, $reasonData): Rule
     {
         $literals = array();
         foreach ($packages as $package) {
@@ -110,7 +109,7 @@ class RuleSetGenerator
      *
      * @phpstan-param ReasonData $reasonData
      */
-    protected function createRule2Literals(BasePackage $issuer, BasePackage $provider, $reason, $reasonData = null)
+    protected function createRule2Literals(BasePackage $issuer, BasePackage $provider, $reason, $reasonData = null): ?Rule
     {
         // ignore self conflict
         if ($issuer === $provider) {
@@ -128,7 +127,7 @@ class RuleSetGenerator
      *
      * @phpstan-param ReasonData $reasonData
      */
-    protected function createMultiConflictRule(array $packages, $reason, $reasonData)
+    protected function createMultiConflictRule(array $packages, $reason, $reasonData): Rule
     {
         $literals = array();
         foreach ($packages as $package) {
@@ -153,7 +152,7 @@ class RuleSetGenerator
      *
      * @return void
      */
-    private function addRule($type, Rule $newRule = null)
+    private function addRule($type, Rule $newRule = null): void
     {
         if (!$newRule) {
             return;
@@ -165,7 +164,7 @@ class RuleSetGenerator
     /**
      * @return void
      */
-    protected function addRulesForPackage(BasePackage $package, PlatformRequirementFilterInterface $platformRequirementFilter)
+    protected function addRulesForPackage(BasePackage $package, PlatformRequirementFilterInterface $platformRequirementFilter): void
     {
         /** @var \SplQueue<BasePackage> */
         $workQueue = new \SplQueue;
@@ -219,7 +218,7 @@ class RuleSetGenerator
     /**
      * @return void
      */
-    protected function addConflictRules(PlatformRequirementFilterInterface $platformRequirementFilter)
+    protected function addConflictRules(PlatformRequirementFilterInterface $platformRequirementFilter): void
     {
         /** @var BasePackage $package */
         foreach ($this->addedMap as $package) {
@@ -260,7 +259,7 @@ class RuleSetGenerator
     /**
      * @return void
      */
-    protected function addRulesForRequest(Request $request, PlatformRequirementFilterInterface $platformRequirementFilter)
+    protected function addRulesForRequest(Request $request, PlatformRequirementFilterInterface $platformRequirementFilter): void
     {
         foreach ($request->getFixedPackages() as $package) {
             if ($package->id == -1) {
@@ -306,7 +305,7 @@ class RuleSetGenerator
     /**
      * @return void
      */
-    protected function addRulesForRootAliases(PlatformRequirementFilterInterface $platformRequirementFilter)
+    protected function addRulesForRootAliases(PlatformRequirementFilterInterface $platformRequirementFilter): void
     {
         foreach ($this->pool->getPackages() as $package) {
             // ensure that rules for root alias packages and aliases of packages which were loaded are also loaded
@@ -324,7 +323,7 @@ class RuleSetGenerator
     /**
      * @return RuleSet
      */
-    public function getRulesFor(Request $request, PlatformRequirementFilterInterface $platformRequirementFilter = null)
+    public function getRulesFor(Request $request, PlatformRequirementFilterInterface $platformRequirementFilter = null): RuleSet
     {
         $platformRequirementFilter = $platformRequirementFilter ?: PlatformRequirementFilterFactory::ignoreNothing();
 
