@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -57,7 +57,7 @@ class PostFileDownloadEvent extends Event
      * @param string      $type     The type (package or metadata).
      * @param mixed       $context  Additional context for the download.
      */
-    public function __construct($name, $fileName, $checksum, $url, $type, $context = null)
+    public function __construct(string $name, ?string $fileName, ?string $checksum, string $url, string $type, $context = null)
     {
         /** @phpstan-ignore-next-line */
         if ($context === null && $type instanceof PackageInterface) {
@@ -81,7 +81,7 @@ class PostFileDownloadEvent extends Event
      *
      * @return string|null
      */
-    public function getFileName()
+    public function getFileName(): ?string
     {
         return $this->fileName;
     }
@@ -91,7 +91,7 @@ class PostFileDownloadEvent extends Event
      *
      * @return string|null
      */
-    public function getChecksum()
+    public function getChecksum(): ?string
     {
         return $this->checksum;
     }
@@ -101,7 +101,7 @@ class PostFileDownloadEvent extends Event
      *
      * @return string
      */
-    public function getUrl()
+    public function getUrl(): string
     {
         return $this->url;
     }
@@ -127,7 +127,7 @@ class PostFileDownloadEvent extends Event
      * @return \Composer\Package\PackageInterface|null The package.
      * @deprecated Use getContext instead
      */
-    public function getPackage()
+    public function getPackage(): ?PackageInterface
     {
         trigger_error('PostFileDownloadEvent::getPackage is deprecated since Composer 2.1, use getContext instead.', E_USER_DEPRECATED);
         $context = $this->getContext();
@@ -140,7 +140,7 @@ class PostFileDownloadEvent extends Event
      *
      * @return string
      */
-    public function getType()
+    public function getType(): string
     {
         return $this->type;
     }
