@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -14,6 +14,7 @@ namespace Composer\Test;
 
 use Composer\Pcre\Preg;
 use Composer\Util\Filesystem;
+use Composer\Util\Platform;
 use Symfony\Component\Finder\Finder;
 use Symfony\Component\Process\Process;
 
@@ -31,15 +32,16 @@ class AllFunctionalTest extends TestCase
      */
     private static $pharPath;
 
-    public function setUp()
+    public function setUp(): void
     {
-        $this->oldcwd = getcwd();
+        $this->oldcwd = Platform::getCwd();
 
         chdir(__DIR__.'/Fixtures/functional');
     }
 
-    public function tearDown()
+    protected function tearDown(): void
     {
+        parent::tearDown();
         if ($this->oldcwd) {
             chdir($this->oldcwd);
         }
@@ -51,18 +53,18 @@ class AllFunctionalTest extends TestCase
         }
     }
 
-    public static function setUpBeforeClass()
+    public static function setUpBeforeClass(): void
     {
         self::$pharPath = self::getUniqueTmpDirectory() . '/composer.phar';
     }
 
-    public static function tearDownAfterClass()
+    public static function tearDownAfterClass(): void
     {
         $fs = new Filesystem;
         $fs->removeDirectory(dirname(self::$pharPath));
     }
 
-    public function testBuildPhar()
+    public function testBuildPhar(): void
     {
         if (defined('HHVM_VERSION')) {
             $this->markTestSkipped('Building the phar does not work on HHVM.');
@@ -84,13 +86,7 @@ class AllFunctionalTest extends TestCase
             }
         }
 
-        // TODO in v2.3 always call with an array
-        if (method_exists('Symfony\Component\Process\Process', 'fromShellCommandline')) {
-            $proc = new Process(array((defined('PHP_BINARY') ? PHP_BINARY : 'php'), '-dphar.readonly=0', './bin/compile'), $target);
-        } else {
-            // @phpstan-ignore-next-line
-            $proc = new Process((defined('PHP_BINARY') ? escapeshellcmd(PHP_BINARY) : 'php').' -dphar.readonly=0 '.escapeshellarg('./bin/compile'), $target);
-        }
+        $proc = new Process([PHP_BINARY, '-dphar.readonly=0', './bin/compile'], $target);
         $exitcode = $proc->run();
 
         if ($exitcode !== 0 || trim($proc->getOutput())) {
@@ -105,7 +101,7 @@ class AllFunctionalTest extends TestCase
      * @depends testBuildPhar
      * @param string $testFile
      */
-    public function testIntegration($testFile)
+    public function testIntegration(string $testFile): void
     {
         $testData = $this->parseTestFile($testFile);
         $this->testDir = self::getUniqueTmpDirectory();
@@ -123,18 +119,10 @@ class AllFunctionalTest extends TestCase
             'COMPOSER_CACHE_DIR' => $this->testDir.'cache',
         );
 
-        // TODO in v2.3 always call with an array
-        if (method_exists('Symfony\Component\Process\Process', 'fromShellCommandline')) {
-            $cmd = array((defined('PHP_BINARY') ? PHP_BINARY : 'php'), self::$pharPath, '--no-ansi', $testData['RUN']);
-            $proc = new Process($cmd, $this->testDir, $env, null, 300);
-        } else {
-            $cmd = (defined('PHP_BINARY') ? escapeshellcmd(PHP_BINARY) : 'php') .' '.escapeshellarg(self::$pharPath).' --no-ansi '.$testData['RUN'];
-            // @phpstan-ignore-next-line
-            $proc = new Process($cmd, $this->testDir, $env, null, 300);
-        }
+        $proc = Process::fromShellCommandline(escapeshellcmd(PHP_BINARY).' '.escapeshellarg(self::$pharPath).' --no-ansi '.$testData['RUN'], $this->testDir, $env, null, 300);
         $output = '';
 
-        $exitcode = $proc->run(function ($type, $buffer) use (&$output) {
+        $exitCode = $proc->run(function ($type, $buffer) use (&$output): void {
             $output .= $buffer;
         });
 
@@ -176,27 +164,27 @@ class AllFunctionalTest extends TestCase
             }
         }
         if (isset($testData['EXPECT-REGEX'])) {
-            $this->assertRegExp($testData['EXPECT-REGEX'], $this->cleanOutput($output));
+            $this->assertMatchesRegularExpression($testData['EXPECT-REGEX'], $this->cleanOutput($output));
         }
         if (isset($testData['EXPECT-REGEXES'])) {
             $cleanOutput = $this->cleanOutput($output);
             foreach (explode("\n", $testData['EXPECT-REGEXES']) as $regex) {
-                $this->assertRegExp($regex, $cleanOutput, 'Output: '.$output);
+                $this->assertMatchesRegularExpression($regex, $cleanOutput, 'Output: '.$output);
             }
         }
         if (isset($testData['EXPECT-EXIT-CODE'])) {
-            $this->assertSame($testData['EXPECT-EXIT-CODE'], $exitcode);
+            $this->assertSame($testData['EXPECT-EXIT-CODE'], $exitCode);
         }
     }
 
     /**
      * @return array<string, array<string>>
      */
-    public function getTestFiles()
+    public function getTestFiles(): array
     {
         $tests = array();
         foreach (Finder::create()->in(__DIR__.'/Fixtures/functional')->name('*.test')->files() as $file) {
-            $tests[basename($file)] = array($file->getRealPath());
+            $tests[$file->getFilename()] = array((string) $file);
         }
 
         return $tests;
@@ -204,9 +192,9 @@ class AllFunctionalTest extends TestCase
 
     /**
      * @param string $file
-     * @return array<string, int|string>
+     * @return array{RUN: string, EXPECT?: string, EXPECT-EXIT-CODE?: int, EXPECT-REGEX?: string, EXPECT-REGEXES?: string, TEST?: string}
      */
-    private function parseTestFile($file)
+    private function parseTestFile(string $file): array
     {
         $tokens = Preg::split('#(?:^|\n*)--([A-Z-]+)--\n#', file_get_contents($file), -1, PREG_SPLIT_DELIM_CAPTURE);
         $data = array();
@@ -261,14 +249,14 @@ class AllFunctionalTest extends TestCase
             throw new \RuntimeException('The test file must have a section named "EXPECT", "EXPECT-REGEX", or "EXPECT-REGEXES".');
         }
 
-        return $data;
+        return $data; // @phpstan-ignore-line
     }
 
     /**
      * @param string $output
      * @return string
      */
-    private function cleanOutput($output)
+    private function cleanOutput(string $output): string
     {
         $processed = '';
 
