@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -13,6 +13,9 @@
 namespace Composer\Test;
 
 use Composer\Config;
+use Composer\IO\BaseIO;
+use Composer\IO\IOInterface;
+use Composer\IO\NullIO;
 use Composer\Util\Platform;
 
 class ConfigTest extends TestCase
@@ -21,9 +24,9 @@ class ConfigTest extends TestCase
      * @dataProvider dataAddPackagistRepository
      * @param mixed[] $expected
      * @param mixed[] $localConfig
-     * @param ?mixed[] $systemConfig
+     * @param ?array<mixed> $systemConfig
      */
-    public function testAddPackagistRepository($expected, $localConfig, $systemConfig = null)
+    public function testAddPackagistRepository(array $expected, array $localConfig, ?array $systemConfig = null): void
     {
         $config = new Config(false);
         if ($systemConfig) {
@@ -34,7 +37,7 @@ class ConfigTest extends TestCase
         $this->assertEquals($expected, $config->getRepositories());
     }
 
-    public function dataAddPackagistRepository()
+    public function dataAddPackagistRepository(): array
     {
         $data = array();
         $data['local config inherits system defaults'] = array(
@@ -141,7 +144,7 @@ class ConfigTest extends TestCase
         return $data;
     }
 
-    public function testPreferredInstallAsString()
+    public function testPreferredInstallAsString(): void
     {
         $config = new Config(false);
         $config->merge(array('config' => array('preferred-install' => 'source')));
@@ -150,7 +153,7 @@ class ConfigTest extends TestCase
         $this->assertEquals('dist', $config->get('preferred-install'));
     }
 
-    public function testMergePreferredInstall()
+    public function testMergePreferredInstall(): void
     {
         $config = new Config(false);
         $config->merge(array('config' => array('preferred-install' => 'dist')));
@@ -162,7 +165,7 @@ class ConfigTest extends TestCase
         $this->assertEquals(array('foo/*' => 'source', '*' => 'dist'), $config->get('preferred-install'));
     }
 
-    public function testMergeGithubOauth()
+    public function testMergeGithubOauth(): void
     {
         $config = new Config(false);
         $config->merge(array('config' => array('github-oauth' => array('foo' => 'bar'))));
@@ -171,7 +174,7 @@ class ConfigTest extends TestCase
         $this->assertEquals(array('foo' => 'bar', 'bar' => 'baz'), $config->get('github-oauth'));
     }
 
-    public function testVarReplacement()
+    public function testVarReplacement(): void
     {
         $config = new Config(false);
         $config->merge(array('config' => array('a' => 'b', 'c' => '{$a}')));
@@ -183,7 +186,7 @@ class ConfigTest extends TestCase
         $this->assertEquals($home.'/foo', $config->get('cache-dir'));
     }
 
-    public function testRealpathReplacement()
+    public function testRealpathReplacement(): void
     {
         $config = new Config(false, '/foo/bar');
         $config->merge(array('config' => array(
@@ -198,7 +201,7 @@ class ConfigTest extends TestCase
         $this->assertEquals('/baz', $config->get('cache-dir'));
     }
 
-    public function testStreamWrapperDirs()
+    public function testStreamWrapperDirs(): void
     {
         $config = new Config(false, '/foo/bar');
         $config->merge(array('config' => array(
@@ -208,7 +211,7 @@ class ConfigTest extends TestCase
         $this->assertEquals('s3://baz', $config->get('cache-dir'));
     }
 
-    public function testFetchingRelativePaths()
+    public function testFetchingRelativePaths(): void
     {
         $config = new Config(false, '/foo/bar');
         $config->merge(array('config' => array(
@@ -222,7 +225,7 @@ class ConfigTest extends TestCase
         $this->assertEquals('vendor/foo', $config->get('bin-dir', Config::RELATIVE_PATHS));
     }
 
-    public function testOverrideGithubProtocols()
+    public function testOverrideGithubProtocols(): void
     {
         $config = new Config(false);
         $config->merge(array('config' => array('github-protocols' => array('https', 'ssh'))));
@@ -231,7 +234,7 @@ class ConfigTest extends TestCase
         $this->assertEquals(array('https'), $config->get('github-protocols'));
     }
 
-    public function testGitDisabledByDefaultInGithubProtocols()
+    public function testGitDisabledByDefaultInGithubProtocols(): void
     {
         $config = new Config(false);
         $config->merge(array('config' => array('github-protocols' => array('https', 'git'))));
@@ -247,7 +250,7 @@ class ConfigTest extends TestCase
      *
      * @param string $url
      */
-    public function testAllowedUrlsPass($url)
+    public function testAllowedUrlsPass(string $url): void
     {
         $config = new Config(false);
         $config->prohibitUrlByConfig($url);
@@ -258,12 +261,10 @@ class ConfigTest extends TestCase
      *
      * @param string $url
      */
-    public function testProhibitedUrlsThrowException($url)
+    public function testProhibitedUrlsThrowException(string $url): void
     {
-        $this->setExpectedException(
-            'Composer\Downloader\TransportException',
-            'Your configuration does not allow connections to ' . $url
-        );
+        self::expectException('Composer\Downloader\TransportException');
+        self::expectExceptionMessage('Your configuration does not allow connections to ' . $url);
         $config = new Config(false);
         $config->prohibitUrlByConfig($url);
     }
@@ -271,7 +272,7 @@ class ConfigTest extends TestCase
     /**
      * @return string[][] List of test URLs that should pass strict security
      */
-    public function allowedUrlProvider()
+    public function allowedUrlProvider(): array
     {
         $urls = array(
             'https://packagist.org',
@@ -284,7 +285,7 @@ class ConfigTest extends TestCase
             'ssh://[user@]host.xz[:port]/path/to/repo.git/',
         );
 
-        return array_combine($urls, array_map(function ($e) {
+        return array_combine($urls, array_map(function ($e): array {
             return array($e);
         }, $urls));
     }
@@ -292,7 +293,7 @@ class ConfigTest extends TestCase
     /**
      * @return string[][] List of test URLs that should not pass strict security
      */
-    public function prohibitedUrlProvider()
+    public function prohibitedUrlProvider(): array
     {
         $urls = array(
             'http://packagist.org',
@@ -305,15 +306,33 @@ class ConfigTest extends TestCase
             'git://5.6.7.8/git.git',
         );
 
-        return array_combine($urls, array_map(function ($e) {
+        return array_combine($urls, array_map(function ($e): array {
             return array($e);
         }, $urls));
     }
 
+    public function testProhibitedUrlsWarningVerifyPeer(): void
+    {
+        $io = $this->getMockBuilder(IOInterface::class)->disableOriginalConstructor()->getMock();
+
+        $io
+            ->expects($this->once())
+            ->method('writeError')
+            ->with($this->equalTo('<warning>Warning: Accessing example.org with verify_peer and verify_peer_name disabled.</warning>'));
+
+        $config = new Config(false);
+        $config->prohibitUrlByConfig('https://example.org', $io, [
+            'ssl' => [
+                'verify_peer' => false,
+                'verify_peer_name' => false,
+            ]
+        ]);
+    }
+
     /**
      * @group TLS
      */
-    public function testDisableTlsCanBeOverridden()
+    public function testDisableTlsCanBeOverridden(): void
     {
         $config = new Config;
         $config->merge(
@@ -326,7 +345,7 @@ class ConfigTest extends TestCase
         $this->assertTrue($config->get('disable-tls'));
     }
 
-    public function testProcessTimeout()
+    public function testProcessTimeout(): void
     {
         Platform::putEnv('COMPOSER_PROCESS_TIMEOUT', '0');
         $config = new Config(true);
@@ -336,7 +355,7 @@ class ConfigTest extends TestCase
         $this->assertEquals(0, $result);
     }
 
-    public function testHtaccessProtect()
+    public function testHtaccessProtect(): void
     {
         Platform::putEnv('COMPOSER_HTACCESS_PROTECT', '0');
         $config = new Config(true);
@@ -346,7 +365,7 @@ class ConfigTest extends TestCase
         $this->assertEquals(0, $result);
     }
 
-    public function testGetSourceOfValue()
+    public function testGetSourceOfValue(): void
     {
         Platform::clearEnv('COMPOSER_PROCESS_TIMEOUT');
 
@@ -362,7 +381,7 @@ class ConfigTest extends TestCase
         $this->assertSame('phpunit-test', $config->getSourceOfValue('process-timeout'));
     }
 
-    public function testGetSourceOfValueEnvVariables()
+    public function testGetSourceOfValueEnvVariables(): void
     {
         Platform::putEnv('COMPOSER_HTACCESS_PROTECT', '0');
         $config = new Config;
@@ -371,4 +390,22 @@ class ConfigTest extends TestCase
 
         $this->assertEquals('COMPOSER_HTACCESS_PROTECT', $result);
     }
+
+    public function testGetDefaultsToAnEmptyArray(): void
+    {
+        $config = new Config;
+        $keys = [
+            'bitbucket-oauth',
+            'github-oauth',
+            'gitlab-oauth',
+            'gitlab-token',
+            'http-basic',
+            'bearer',
+        ];
+        foreach ($keys as $key) {
+            $value = $config->get($key);
+            $this->assertIsArray($value);
+            $this->assertCount(0, $value);
+        }
+    }
 }
