@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -23,7 +23,7 @@ class ValidatingArrayLoaderTest extends TestCase
      *
      * @param array<string, mixed> $config
      */
-    public function testLoadSuccess($config)
+    public function testLoadSuccess(array $config): void
     {
         $internalLoader = $this->getMockBuilder('Composer\Package\Loader\LoaderInterface')->getMock();
         $internalLoader
@@ -35,7 +35,7 @@ class ValidatingArrayLoaderTest extends TestCase
         $loader->load($config);
     }
 
-    public function successProvider()
+    public function successProvider(): array
     {
         return array(
             array( // minimal
@@ -212,7 +212,7 @@ class ValidatingArrayLoaderTest extends TestCase
      * @param array<string, mixed> $config
      * @param string[]             $expectedErrors
      */
-    public function testLoadFailureThrowsException($config, $expectedErrors)
+    public function testLoadFailureThrowsException(array $config, array $expectedErrors): void
     {
         $internalLoader = $this->getMockBuilder('Composer\Package\Loader\LoaderInterface')->getMock();
         $loader = new ValidatingArrayLoader($internalLoader, true, null, ValidatingArrayLoader::CHECK_ALL);
@@ -233,7 +233,7 @@ class ValidatingArrayLoaderTest extends TestCase
      * @param array<string, mixed> $config
      * @param string[]             $expectedWarnings
      */
-    public function testLoadWarnings($config, $expectedWarnings)
+    public function testLoadWarnings(array $config, array $expectedWarnings): void
     {
         $internalLoader = $this->getMockBuilder('Composer\Package\Loader\LoaderInterface')->getMock();
         $loader = new ValidatingArrayLoader($internalLoader, true, null, ValidatingArrayLoader::CHECK_ALL);
@@ -252,7 +252,7 @@ class ValidatingArrayLoaderTest extends TestCase
      * @param string[]             $expectedWarnings
      * @param bool                 $mustCheck
      */
-    public function testLoadSkipsWarningDataWhenIgnoringErrors($config, $expectedWarnings, $mustCheck = true)
+    public function testLoadSkipsWarningDataWhenIgnoringErrors(array $config, array $expectedWarnings, bool $mustCheck = true): void
     {
         if (!$mustCheck) {
             $this->assertTrue(true);
@@ -270,7 +270,7 @@ class ValidatingArrayLoaderTest extends TestCase
         $loader->load($config);
     }
 
-    public function errorProvider()
+    public function errorProvider(): array
     {
         $invalidNames = array(
             'foo',
@@ -352,18 +352,6 @@ class ValidatingArrayLoaderTest extends TestCase
                     'name : Foo/Bar is invalid, it should not contain uppercase characters. We suggest using foo/bar instead.',
                 ),
             ),
-            array(
-                array(
-                    'name' => 'foo/bar',
-                    'require' => array(
-                        'Foo/Baz' => '^1.0',
-                    ),
-                ),
-                array(
-                    'require.Foo/Baz is invalid, it should not contain uppercase characters. Please use foo/baz instead.',
-                ),
-                false,
-            ),
             array(
                 array(
                     'name' => 'foo/bar',
@@ -417,10 +405,24 @@ class ValidatingArrayLoaderTest extends TestCase
                     'require.foo/Bar : a package cannot set a require on itself',
                 ),
             ),
+            array(
+                array(
+                    'name' => 'foo/bar',
+                    'source' => array('url' => 1),
+                    'dist' => array('url' => null),
+                ),
+                array(
+                    'source.type : must be present',
+                    'source.url : should be a string, integer given',
+                    'source.reference : must be present',
+                    'dist.type : must be present',
+                    'dist.url : must be present',
+                ),
+            ),
         ));
     }
 
-    public function warningProvider()
+    public function warningProvider(): array
     {
         return array(
             array(
@@ -509,6 +511,18 @@ class ValidatingArrayLoaderTest extends TestCase
                 ),
                 false,
             ),
+            array(
+                array(
+                    'name' => 'foo/bar',
+                    'require' => array(
+                        'Foo/Baz' => '^1.0',
+                    ),
+                ),
+                array(
+                    'require.Foo/Baz is invalid, it should not contain uppercase characters. Please use foo/baz instead.',
+                ),
+                false,
+            ),
         );
     }
 }
