@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -17,10 +17,8 @@ use Composer\Json\JsonFile;
 use Composer\Repository\ComposerRepository;
 use Composer\Repository\RepositoryInterface;
 use Composer\Test\Mock\FactoryMock;
-use Composer\Test\Mock\HttpDownloaderMock;
 use Composer\Test\TestCase;
 use Composer\Package\Loader\ArrayLoader;
-use Composer\Package\Version\VersionParser;
 
 class ComposerRepositoryTest extends TestCase
 {
@@ -30,14 +28,14 @@ class ComposerRepositoryTest extends TestCase
      * @param mixed[]              $expected
      * @param array<string, mixed> $repoPackages
      */
-    public function testLoadData(array $expected, array $repoPackages)
+    public function testLoadData(array $expected, array $repoPackages): void
     {
         $repoConfig = array(
             'url' => 'http://example.org',
         );
 
         $repository = $this->getMockBuilder('Composer\Repository\ComposerRepository')
-            ->setMethods(array('loadRootServerFile', 'createPackages'))
+            ->onlyMethods(array('loadRootServerFile'))
             ->setConstructorArgs(array(
                 $repoConfig,
                 new NullIO,
@@ -52,25 +50,18 @@ class ComposerRepositoryTest extends TestCase
             ->method('loadRootServerFile')
             ->will($this->returnValue($repoPackages));
 
-        $stubs = array();
-        foreach ($expected as $at => $arg) {
-            $stubs[] = $this->getPackage('stub/stub', '1.0.0');
-        }
-
-        $repository
-            ->expects($this->at(2))
-            ->method('createPackages')
-            ->with($this->identicalTo($expected), $this->equalTo('root file (http://example.org/packages.json)'))
-            ->will($this->returnValue($stubs));
-
         // Triggers initialization
         $packages = $repository->getPackages();
 
         // Final sanity check, ensure the correct number of packages were added.
         $this->assertCount(count($expected), $packages);
+
+        foreach ($expected as $index => $pkg) {
+            self::assertSame($pkg['name'].' '.$pkg['version'], $packages[$index]->getName().' '.$packages[$index]->getPrettyVersion());
+        }
     }
 
-    public function loadDataProvider()
+    public function loadDataProvider(): array
     {
         return array(
             // Old repository format
@@ -101,7 +92,7 @@ class ComposerRepositoryTest extends TestCase
         );
     }
 
-    public function testWhatProvides()
+    public function testWhatProvides(): void
     {
         $repo = $this->getMockBuilder('Composer\Repository\ComposerRepository')
             ->setConstructorArgs(array(
@@ -111,7 +102,7 @@ class ComposerRepositoryTest extends TestCase
                 $this->getMockBuilder('Composer\Util\HttpDownloader')->disableOriginalConstructor()->getMock(),
                 $this->getMockBuilder('Composer\EventDispatcher\EventDispatcher')->disableOriginalConstructor()->getMock(),
             ))
-            ->setMethods(array('fetchFile'))
+            ->onlyMethods(array('fetchFile'))
             ->getMock();
 
         $cache = $this->getMockBuilder('Composer\Cache')->disableOriginalConstructor()->getMock();
@@ -156,7 +147,6 @@ class ComposerRepositoryTest extends TestCase
                 ),
             )));
 
-        $versionParser = new VersionParser();
         $reflMethod = new \ReflectionMethod($repo, 'whatProvides');
         $reflMethod->setAccessible(true);
         $packages = $reflMethod->invoke($repo, 'a');
@@ -166,7 +156,7 @@ class ComposerRepositoryTest extends TestCase
         $this->assertSame($packages['2'], $packages['2-alias']->getAliasOf());
     }
 
-    public function testSearchWithType()
+    public function testSearchWithType(): void
     {
         $repoConfig = array(
             'url' => 'http://example.org',
@@ -181,16 +171,22 @@ class ComposerRepositoryTest extends TestCase
             ),
         );
 
-        $httpDownloader = new HttpDownloaderMock(array(
-            'http://example.org/packages.json' => JsonFile::encode(array('search' => '/search.json?q=%query%&type=%type%')),
-            'http://example.org/search.json?q=foo&type=composer-plugin' => JsonFile::encode($result),
-            'http://example.org/search.json?q=foo&type=library' => JsonFile::encode(array()),
-        ));
+        $httpDownloader = $this->getHttpDownloaderMock();
+        $httpDownloader->expects(
+            [
+                ['url' => 'http://example.org/packages.json', 'body' => JsonFile::encode(array('search' => '/search.json?q=%query%&type=%type%'))],
+                ['url' => 'http://example.org/search.json?q=foo&type=composer-plugin', 'body' => JsonFile::encode($result)],
+                ['url' => 'http://example.org/search.json?q=foo&type=library', 'body' => JsonFile::encode(array())],
+            ],
+            true
+        );
         $eventDispatcher = $this->getMockBuilder('Composer\EventDispatcher\EventDispatcher')
             ->disableOriginalConstructor()
             ->getMock();
 
-        $repository = new ComposerRepository($repoConfig, new NullIO, FactoryMock::createConfig(), $httpDownloader, $eventDispatcher);
+        $config = FactoryMock::createConfig();
+        $config->merge(['config' => ['cache-read-only' => true]]);
+        $repository = new ComposerRepository($repoConfig, new NullIO, $config, $httpDownloader, $eventDispatcher);
 
         $this->assertSame(
             array(array('name' => 'foo', 'description' => null)),
@@ -202,40 +198,37 @@ class ComposerRepositoryTest extends TestCase
         );
     }
 
-    public function testSearchWithSpecialChars()
+    public function testSearchWithSpecialChars(): void
     {
         $repoConfig = array(
             'url' => 'http://example.org',
         );
 
-        $result = array(
-            'results' => array(
-                array(
-                    'name' => 'foo',
-                    'description' => null,
-                ),
-            ),
+        $httpDownloader = $this->getHttpDownloaderMock();
+        $httpDownloader->expects(
+            [
+                ['url' => 'http://example.org/packages.json', 'body' => JsonFile::encode(array('search' => '/search.json?q=%query%&type=%type%'))],
+                ['url' => 'http://example.org/search.json?q=foo+bar&type=', 'body' => JsonFile::encode(array())],
+            ],
+            true
         );
-
-        $httpDownloader = new HttpDownloaderMock(array(
-            'http://example.org/packages.json' => JsonFile::encode(array('search' => '/search.json?q=%query%&type=%type%')),
-            'http://example.org/search.json?q=foo+bar&type=' => JsonFile::encode(array()),
-        ));
         $eventDispatcher = $this->getMockBuilder('Composer\EventDispatcher\EventDispatcher')
             ->disableOriginalConstructor()
             ->getMock();
 
-        $repository = new ComposerRepository($repoConfig, new NullIO, FactoryMock::createConfig(), $httpDownloader, $eventDispatcher);
+        $config = FactoryMock::createConfig();
+        $config->merge(['config' => ['cache-read-only' => true]]);
+        $repository = new ComposerRepository($repoConfig, new NullIO, $config, $httpDownloader, $eventDispatcher);
 
         $this->assertEmpty(
             $repository->search('foo bar', RepositoryInterface::SEARCH_FULLTEXT)
         );
     }
 
-    public function testSearchWithAbandonedPackages()
+    public function testSearchWithAbandonedPackages(): void
     {
         $repoConfig = array(
-            'url' => 'http://2.example.org',
+            'url' => 'http://example.org',
         );
 
         $result = array(
@@ -253,15 +246,22 @@ class ComposerRepositoryTest extends TestCase
             ),
         );
 
-        $httpDownloader = new HttpDownloaderMock(array(
-            'http://2.example.org/packages.json' => JsonFile::encode(array('search' => '/search.json?q=%query%')),
-            'http://2.example.org/search.json?q=foo' => JsonFile::encode($result),
-        ));
+        $httpDownloader = $this->getHttpDownloaderMock();
+        $httpDownloader->expects(
+            [
+                ['url' => 'http://example.org/packages.json', 'body' => JsonFile::encode(array('search' => '/search.json?q=%query%'))],
+                ['url' => 'http://example.org/search.json?q=foo', 'body' => JsonFile::encode($result)],
+            ],
+            true
+        );
+
         $eventDispatcher = $this->getMockBuilder('Composer\EventDispatcher\EventDispatcher')
             ->disableOriginalConstructor()
             ->getMock();
 
-        $repository = new ComposerRepository($repoConfig, new NullIO, FactoryMock::createConfig(), $httpDownloader, $eventDispatcher);
+        $config = FactoryMock::createConfig();
+        $config->merge(['config' => ['cache-read-only' => true]]);
+        $repository = new ComposerRepository($repoConfig, new NullIO, $config, $httpDownloader, $eventDispatcher);
 
         $this->assertSame(
             array(
@@ -279,7 +279,7 @@ class ComposerRepositoryTest extends TestCase
      * @param string $url
      * @param string $repositoryUrl
      */
-    public function testCanonicalizeUrl($expected, $url, $repositoryUrl)
+    public function testCanonicalizeUrl(string $expected, string $url, string $repositoryUrl): void
     {
         $repository = new ComposerRepository(
             array('url' => $repositoryUrl),
@@ -303,7 +303,7 @@ class ComposerRepositoryTest extends TestCase
         $this->assertSame($expected, $method->invoke($repository, $url));
     }
 
-    public function provideCanonicalizeUrlTestCases()
+    public function provideCanonicalizeUrlTestCases(): array
     {
         return array(
             array(
@@ -341,17 +341,24 @@ class ComposerRepositoryTest extends TestCase
         );
     }
 
-    public function testGetProviderNamesWillReturnPartialPackageNames()
+    public function testGetProviderNamesWillReturnPartialPackageNames(): void
     {
-        $httpDownloader = new HttpDownloaderMock(array(
-            'http://example.org/packages.json' => JsonFile::encode(array(
-                'providers-lazy-url' => '/foo/p/%package%.json',
-                'packages' => array('foo/bar' => array(
-                    'dev-branch' => array('name' => 'foo/bar'),
-                    'v1.0.0' => array('name' => 'foo/bar'),
-                )),
-            )),
-        ));
+        $httpDownloader = $this->getHttpDownloaderMock();
+        $httpDownloader->expects(
+            [
+                [
+                    'url' => 'http://example.org/packages.json',
+                    'body' => JsonFile::encode(array(
+                        'providers-lazy-url' => '/foo/p/%package%.json',
+                        'packages' => array('foo/bar' => array(
+                            'dev-branch' => array('name' => 'foo/bar'),
+                            'v1.0.0' => array('name' => 'foo/bar'),
+                        )),
+                    )),
+                ],
+            ],
+            true
+        );
 
         $repository = new ComposerRepository(
             array('url' => 'http://example.org/packages.json'),
