@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -21,7 +21,7 @@ use Composer\Test\TestCase;
 
 class InstalledRepositoryTest extends TestCase
 {
-    public function testFindPackagesWithReplacersAndProviders()
+    public function testFindPackagesWithReplacersAndProviders(): void
     {
         $arrayRepoOne = new InstalledArrayRepository;
         $arrayRepoOne->addPackage($foo = $this->getPackage('foo', '1'));
@@ -41,11 +41,11 @@ class InstalledRepositoryTest extends TestCase
         $this->assertEquals(array($foo, $bar2), $repo->findPackagesWithReplacersAndProviders('provided'));
     }
 
-    public function testAddRepository()
+    public function testAddRepository(): void
     {
         $arrayRepoOne = new ArrayRepository;
 
-        $this->setExpectedException('LogicException');
+        self::expectException('LogicException');
 
         new InstalledRepository(array($arrayRepoOne));
     }
