@@ -1,4 +1,4 @@
-<?php
+<?php declare(strict_types=1);
 
 /*
  * This file is part of Composer.
@@ -32,7 +32,7 @@ class AuthHelperTest extends TestCase
     /** @var AuthHelper */
     private $authHelper;
 
-    protected function setUp()
+    protected function setUp(): void
     {
         $this->io = $this
             ->getMockBuilder('Composer\IO\IOInterface')
@@ -44,7 +44,7 @@ class AuthHelperTest extends TestCase
         $this->authHelper = new AuthHelper($this->io, $this->config);
     }
 
-    public function testAddAuthenticationHeaderWithoutAuthCredentials()
+    public function testAddAuthenticationHeaderWithoutAuthCredentials(): void
     {
         $headers = array(
             'Accept-Encoding: gzip',
@@ -64,7 +64,7 @@ class AuthHelperTest extends TestCase
         );
     }
 
-    public function testAddAuthenticationHeaderWithBearerPassword()
+    public function testAddAuthenticationHeaderWithBearerPassword(): void
     {
         $headers = array(
             'Accept-Encoding: gzip',
@@ -87,7 +87,7 @@ class AuthHelperTest extends TestCase
         );
     }
 
-    public function testAddAuthenticationHeaderWithGithubToken()
+    public function testAddAuthenticationHeaderWithGithubToken(): void
     {
         $headers = array(
             'Accept-Encoding: gzip',
@@ -114,7 +114,7 @@ class AuthHelperTest extends TestCase
         );
     }
 
-    public function testAddAuthenticationHeaderWithGitlabOathToken()
+    public function testAddAuthenticationHeaderWithGitlabOathToken(): void
     {
         $headers = array(
             'Accept-Encoding: gzip',
@@ -146,7 +146,7 @@ class AuthHelperTest extends TestCase
         );
     }
 
-    public function gitlabPrivateTokenProvider()
+    public function gitlabPrivateTokenProvider(): array
     {
         return array(
           array('private-token'),
@@ -159,7 +159,7 @@ class AuthHelperTest extends TestCase
      *
      * @param string $password
      */
-    public function testAddAuthenticationHeaderWithGitlabPrivateToken($password)
+    public function testAddAuthenticationHeaderWithGitlabPrivateToken(string $password): void
     {
         $headers = array(
             'Accept-Encoding: gzip',
@@ -191,7 +191,7 @@ class AuthHelperTest extends TestCase
         );
     }
 
-    public function testAddAuthenticationHeaderWithBitbucketOathToken()
+    public function testAddAuthenticationHeaderWithBitbucketOathToken(): void
     {
         $headers = array(
             'Accept-Encoding: gzip',
@@ -223,7 +223,7 @@ class AuthHelperTest extends TestCase
         );
     }
 
-    public function bitbucketPublicUrlProvider()
+    public function bitbucketPublicUrlProvider(): array
     {
         return array(
             array('https://bitbucket.org/user/repo/downloads/whatever'),
@@ -236,7 +236,7 @@ class AuthHelperTest extends TestCase
      *
      * @param string $url
      */
-    public function testAddAuthenticationHeaderWithBitbucketPublicUrl($url)
+    public function testAddAuthenticationHeaderWithBitbucketPublicUrl(string $url): void
     {
         $headers = array(
             'Accept-Encoding: gzip',
@@ -261,7 +261,7 @@ class AuthHelperTest extends TestCase
         );
     }
 
-    public function basicHttpAuthenticationProvider()
+    public function basicHttpAuthenticationProvider(): array
     {
         return array(
             array(
@@ -300,7 +300,7 @@ class AuthHelperTest extends TestCase
      *
      * @phpstan-param array{username: string|null, password: string|null} $auth
      */
-    public function testAddAuthenticationHeaderWithBasicHttpAuthentication($url, $origin, $auth)
+    public function testAddAuthenticationHeaderWithBasicHttpAuthentication(string $url, string $origin, array $auth): void
     {
         $headers = array(
             'Accept-Encoding: gzip',
@@ -338,12 +338,12 @@ class AuthHelperTest extends TestCase
      *
      * @param string $url
      */
-    public function testIsPublicBitBucketDownloadWithBitbucketPublicUrl($url)
+    public function testIsPublicBitBucketDownloadWithBitbucketPublicUrl(string $url): void
     {
         $this->assertTrue($this->authHelper->isPublicBitBucketDownload($url));
     }
 
-    public function testIsPublicBitBucketDownloadWithNonBitbucketPublicUrl()
+    public function testIsPublicBitBucketDownloadWithNonBitbucketPublicUrl(): void
     {
         $this->assertFalse(
             $this->authHelper->isPublicBitBucketDownload(
@@ -352,7 +352,7 @@ class AuthHelperTest extends TestCase
         );
     }
 
-    public function testStoreAuthAutomatically()
+    public function testStoreAuthAutomatically(): void
     {
         $origin = 'github.com';
         $storeAuth = true;
@@ -378,13 +378,12 @@ class AuthHelperTest extends TestCase
 
         $configSource->expects($this->once())
             ->method('addConfigSetting')
-            ->with('http-basic.'.$origin, $auth)
-            ->willReturn($configSource);
+            ->with('http-basic.'.$origin, $auth);
 
         $this->authHelper->storeAuth($origin, $storeAuth);
     }
 
-    public function testStoreAuthWithPromptYesAnswer()
+    public function testStoreAuthWithPromptYesAnswer(): void
     {
         $origin = 'github.com';
         $storeAuth = 'prompt';
@@ -417,7 +416,7 @@ class AuthHelperTest extends TestCase
                 null,
                 'y'
             )
-            ->willReturnCallback(function ($question, $validator, $attempts, $default) use ($answer) {
+            ->willReturnCallback(function ($question, $validator, $attempts, $default) use ($answer): string {
                 $validator($answer);
 
                 return $answer;
@@ -430,13 +429,12 @@ class AuthHelperTest extends TestCase
 
         $configSource->expects($this->once())
             ->method('addConfigSetting')
-            ->with('http-basic.'.$origin, $auth)
-            ->willReturn($configSource);
+            ->with('http-basic.'.$origin, $auth);
 
         $this->authHelper->storeAuth($origin, $storeAuth);
     }
 
-    public function testStoreAuthWithPromptNoAnswer()
+    public function testStoreAuthWithPromptNoAnswer(): void
     {
         $origin = 'github.com';
         $storeAuth = 'prompt';
@@ -465,7 +463,7 @@ class AuthHelperTest extends TestCase
                 null,
                 'y'
             )
-            ->willReturnCallback(function ($question, $validator, $attempts, $default) use ($answer) {
+            ->willReturnCallback(function ($question, $validator, $attempts, $default) use ($answer): string {
                 $validator($answer);
 
                 return $answer;
@@ -474,12 +472,9 @@ class AuthHelperTest extends TestCase
         $this->authHelper->storeAuth($origin, $storeAuth);
     }
 
-    /**
-     * @return void
-     */
-    public function testStoreAuthWithPromptInvalidAnswer()
+    public function testStoreAuthWithPromptInvalidAnswer(): void
     {
-        $this->setExpectedException('RuntimeException');
+        self::expectException('RuntimeException');
 
         $origin = 'github.com';
         $storeAuth = 'prompt';
@@ -508,7 +503,7 @@ class AuthHelperTest extends TestCase
                 null,
                 'y'
             )
-            ->willReturnCallback(function ($question, $validator, $attempts, $default) use ($answer) {
+            ->willReturnCallback(function ($question, $validator, $attempts, $default) use ($answer): string {
                 $validator($answer);
 
                 return $answer;
@@ -517,12 +512,9 @@ class AuthHelperTest extends TestCase
         $this->authHelper->storeAuth($origin, $storeAuth);
     }
 
-    /**
-     * @return void
-     */
-    public function testPromptAuthIfNeededGitLabNoAuthChange()
+    public function testPromptAuthIfNeededGitLabNoAuthChange(): void
     {
-        $this->setExpectedException('Composer\Downloader\TransportException');
+        self::expectException('Composer\Downloader\TransportException');
 
         $origin = 'gitlab.com';
 
@@ -563,7 +555,7 @@ class AuthHelperTest extends TestCase
      *
      * @phpstan-param array{username: string|null, password: string|null} $auth
      */
-    private function expectsAuthentication($origin, $auth)
+    private function expectsAuthentication(string $origin, array $auth): void
     {
         $this->io->expects($this->once())
             ->method('hasAuthentication')
